Learn R Programming

rjazz (version 0.1.7)

list_web_sources: List all the web sources on the Jazz server

Description

Lists all the web sources on the Jazz server. All www resource links and urls are grouped under a "web source" which is just a name to allow removing them with a single call.

Usage

list_web_sources(host = .host.)

Arguments

host

(Optional) the name of the jazz server host (including the port). Usually set just once via set_jazz_host().

Value

Returns the web sources as a vector of string.

Examples

Run this code
# NOT RUN {
set_jazz_host('127.0.0.1:8888')
page <- '<html>\n<body>\n<br/>Hello world!\n</body>\n</html>'
create_web_resource('my_test',
                    '/my_test/hello.html',
                    type_const[['BLOCKTYPE_RAW_MIME_HTML']],
                    page)
# See http://127.0.0.1:8888/my_test/hello.html with a browser.

list_web_sources()
delete_web_source('my_test')
# }

Run the code above in your browser using DataLab