Creates a key for a new block using a RNG. The function uses runif() and does not perform any seed initialization. See .Random.seed for more information on R's random number generation algorithms.
Usage
new_key(host = .host.)
Arguments
host
(Optional) the name of the jazz server host (including the port). Usually set just once via set_jazz_host().
Value
This function returns the newly created key value for further use.